@@ -10,26 +10,26 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.07';
-$DATE = '2004/05/11';
+$VERSION = '0.08';
+$DATE = '2004/05/12';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Data_Secs2.pm' => [qw(0.07 2004/05/11), 'revised 0.06'],
-    'MANIFEST' => [qw(0.07 2004/05/11), 'generated, replaces 0.06'],
-    'Makefile.PL' => [qw(0.07 2004/05/11), 'generated, replaces 0.06'],
-    'README' => [qw(0.07 2004/05/11), 'generated, replaces 0.06'],
-    'lib/Data/Secs2.pm' => [qw(1.22 2004/05/11), 'revised 1.19'],
-    't/Data/Secs2.d' => [qw(0.06 2004/05/11), 'revised 0.05'],
-    't/Data/Secs2.pm' => [qw(0.06 2004/05/11), 'revised 0.05'],
-    't/Data/Secs2.t' => [qw(0.07 2004/05/11), 'revised 0.06'],
-    't/Data/File/Package.pm' => [qw(1.17 2004/05/11), 'revised 1.16'],
-    't/Data/File/SmartNL.pm' => [qw(1.15 2004/05/11), 'revised 1.14'],
-    't/Data/Text/Scrub.pm' => [qw(1.13 2004/05/11), 'revised 1.12'],
-    't/Data/Test/Tech.pm' => [qw(1.24 2004/05/11), 'revised 1.22'],
-    't/Data/Data/SecsPack.pm' => [qw(0.07 2004/05/11), 'revised 0.04'],
-    't/Data/Data/Startup.pm' => [qw(0.06 2004/05/11), 'revised 0.03'],
+    'lib/Docs/Site_SVD/Data_Secs2.pm' => [qw(0.08 2004/05/12), 'revised 0.07'],
+    'MANIFEST' => [qw(0.08 2004/05/12), 'generated, replaces 0.07'],
+    'Makefile.PL' => [qw(0.08 2004/05/12), 'generated, replaces 0.07'],
+    'README' => [qw(0.08 2004/05/12), 'generated, replaces 0.07'],
+    'lib/Data/Secs2.pm' => [qw(1.23 2004/05/12), 'revised 1.22'],
+    't/Data/Secs2.d' => [qw(0.06 2004/05/11), 'unchanged'],
+    't/Data/Secs2.pm' => [qw(0.06 2004/05/11), 'unchanged'],
+    't/Data/Secs2.t' => [qw(0.07 2004/05/11), 'unchanged'],
+    't/Data/File/Package.pm' => [qw(1.17 2004/05/12), 'unchanged'],
+    't/Data/File/SmartNL.pm' => [qw(1.15 2004/05/12), 'unchanged'],
+    't/Data/Text/Scrub.pm' => [qw(1.13 2004/05/12), 'unchanged'],
+    't/Data/Test/Tech.pm' => [qw(1.25 2004/05/12), 'revised 1.24'],
+    't/Data/Data/SecsPack.pm' => [qw(0.07 2004/05/12), 'unchanged'],
+    't/Data/Data/Startup.pm' => [qw(0.06 2004/05/12), 'unchanged'],
 
 );
 
@@ -50,7 +50,7 @@ use vars qw(%INVENTORY);
 
 =head1 NAME
 
- Data::Secs2 - pack, unpack, format between Perl data and SEMI E5-94 nested data
+Docs::Site_SVD::Data_Secs2 - pack, unpack, format between Perl data and SEMI E5-94 nested data
 
 =head1 Title Page
 
@@ -58,13 +58,13 @@ use vars qw(%INVENTORY);
 
  for
 
-  Data::Secs2 - pack, unpack, format between Perl data and SEMI E5-94 nested data
+ Docs::Site_SVD::Data_Secs2 - pack, unpack, format between Perl data and SEMI E5-94 nested data
 
- Revision: E
+ Revision: F
 
- Version: 0.07
+ Version: 0.08
 
- Date: 2004/05/11
+ Date: 2004/05/12
 
  Prepared for: General Public 
 
@@ -93,7 +93,7 @@ no matter how many nests of arrays and hashes it contains.
 
 =head2 1.3 Document overview.
 
-This document releases Data::Secs2 version 0.07
+This document releases Data::Secs2 version 0.08
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -108,7 +108,7 @@ system file specification.
 
 This document releases the file 
 
- Data-Secs2-0.07.tar.gz
+ Data-Secs2-0.08.tar.gz
 
 found at the following repository(s):
 
@@ -195,20 +195,20 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Data_Secs2.pm                              0.07    2004/05/11 revised 0.06
- MANIFEST                                                     0.07    2004/05/11 generated, replaces 0.06
- Makefile.PL                                                  0.07    2004/05/11 generated, replaces 0.06
- README                                                       0.07    2004/05/11 generated, replaces 0.06
- lib/Data/Secs2.pm                                            1.22    2004/05/11 revised 1.19
- t/Data/Secs2.d                                               0.06    2004/05/11 revised 0.05
- t/Data/Secs2.pm                                              0.06    2004/05/11 revised 0.05
- t/Data/Secs2.t                                               0.07    2004/05/11 revised 0.06
- t/Data/File/Package.pm                                       1.17    2004/05/11 revised 1.16
- t/Data/File/SmartNL.pm                                       1.15    2004/05/11 revised 1.14
- t/Data/Text/Scrub.pm                                         1.13    2004/05/11 revised 1.12
- t/Data/Test/Tech.pm                                          1.24    2004/05/11 revised 1.22
- t/Data/Data/SecsPack.pm                                      0.07    2004/05/11 revised 0.04
- t/Data/Data/Startup.pm                                       0.06    2004/05/11 revised 0.03
+ lib/Docs/Site_SVD/Data_Secs2.pm                              0.08    2004/05/12 revised 0.07
+ MANIFEST                                                     0.08    2004/05/12 generated, replaces 0.07
+ Makefile.PL                                                  0.08    2004/05/12 generated, replaces 0.07
+ README                                                       0.08    2004/05/12 generated, replaces 0.07
+ lib/Data/Secs2.pm                                            1.23    2004/05/12 revised 1.22
+ t/Data/Secs2.d                                               0.06    2004/05/11 unchanged
+ t/Data/Secs2.pm                                              0.06    2004/05/11 unchanged
+ t/Data/Secs2.t                                               0.07    2004/05/11 unchanged
+ t/Data/File/Package.pm                                       1.17    2004/05/12 unchanged
+ t/Data/File/SmartNL.pm                                       1.15    2004/05/12 unchanged
+ t/Data/Text/Scrub.pm                                         1.13    2004/05/12 unchanged
+ t/Data/Test/Tech.pm                                          1.25    2004/05/12 revised 1.24
+ t/Data/Data/SecsPack.pm                                      0.07    2004/05/12 unchanged
+ t/Data/Data/Startup.pm                                       0.06    2004/05/12 unchanged
 
 
 =head2 3.3 Changes
@@ -329,6 +329,13 @@ output error messages beside optional C<warns> and C<dies>.
 The C<secs_elementify> subroutine did not handle a numeric zero properly.
 Added test for numeric zero and undef.
 
+=item Data-Secs2-0.08
+
+Documentation woes.
+The SEMI link does not work on. Changed to SEMI, http://www.semi.org.
+The new SVD =head1 NAME is masking out the code program module.
+Changed the SVD =head1 NAME so not same as code program module =head1 NAME
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -367,13 +374,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Data-Secs2-0.07.tar.gz' and download to a temporary
+Right click on 'Data-Secs2-0.08.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Data-Secs2-0.07.tar.gz
- tar -xf Data-Secs2-0.07.tar
+ gunzip Data-Secs2-0.08.tar.gz
+ tar -xf Data-Secs2-0.08.tar
  perl Makefile.PL
  $make test
  $make install
@@ -464,15 +471,15 @@ Plain Old Documentation
 __DATA__
 
 DISTNAME: Data-Secs2^
-VERSION : 0.07^
+VERSION : 0.08^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.06^
-REVISION: E^
+PREVIOUS_RELEASE: 0.07^
+REVISION: F^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: pack, unpack, format, transform between Perl data and SEMI E5-94 SECS-II nested data^
-TITLE   :  Data::Secs2 - pack, unpack, format between Perl data and SEMI E5-94 nested data^
+TITLE   : Docs::Site_SVD::Data_Secs2 - pack, unpack, format between Perl data and SEMI E5-94 nested data^
 END_USER: General Public^
 COPYRIGHT: copyright 2003 2004 Software Diamonds^
 CLASSIFICATION: NONE^
@@ -502,6 +509,9 @@ lib/Data/SecsPack.pm => t/Data/Data/SecsPack.pm
 lib/Data/Startup.pm => t/Data/Data/Startup.pm
 ^
 
+REPLACE:
+^
+
 PREREQ_PM:
 'Data::SecsPack' => '0.06',
 'Data::Startup' => '0.02'
@@ -628,6 +638,13 @@ output error messages beside optional C<warns> and C<dies>.
 The C<secs_elementify> subroutine did not handle a numeric zero properly.
 Added test for numeric zero and undef.
 
+\=item Data-Secs2-0.08
+
+Documentation woes.
+The SEMI link does not work on. Changed to SEMI, http://www.semi.org.
+The new SVD =head1 NAME is masking out the code program module.
+Changed the SVD =head1 NAME so not same as code program module =head1 NAME
+
 \=back
 
 ^
@@ -793,3 +810,13 @@ HTML:
 
 
 
+
+
+
+
+
+
+
+
+
+
